@@ -17,7 +17,7 @@ use Plack::Util::Accessor qw( rules handler status );
 
 # RECOMMEND PREREQ: Ref::Util::XS
 
-our $VERSION = 'v0.12.0';
+our $VERSION = 'v0.12.1';
 
 
 sub prepare_app {
@@ -79,7 +79,7 @@ Plack::Middleware::Security::Simple - A simple security filter for Plack
 
 =head1 VERSION
 
-version v0.12.0
+version v0.12.1
 
 =head1 SYNOPSIS
 
@@ -147,11 +147,7 @@ when a resource is blocked.  It defaults to 400 (Bad Request).
 
 Since v0.9.0, the this module requires Perl v5.14 or later.
 
-Future releases may only support Perl versions released in the last ten years.
-
-If you need this module on Perl v5.10, please use one of the v0.8.x
-versions of this module.  Significant bug or security fixes may be
-backported to those versions.
+Future releases may only support Perl versions released in the last ten (10) years.
 
 =head1 SEE ALSO
 
@@ -175,13 +171,18 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head2 Reporting Security Vulnerabilities
+
+Security issues should not be reported on the bugtracker website. Please see F<SECURITY.md> for instructions how to
+report security vulnerabilities
+
 =head1 AUTHOR
 
 Robert Rothenberg <rrwo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014,2018-2024 by Robert Rothenberg.
+This software is Copyright (c) 2014,2018-2025 by Robert Rothenberg.
 
 This is free software, licensed under:
 
